from flask import Flask, abort, request
from tempfile import NamedTemporaryFile
from dotenv import load_dotenv
import os
import whisper
import torch
import sys
import re

load_dotenv()

HARPYIA_PROMPT = os.getenv('HARPYIA_PROMPT') or 'спасите помогите на помощь пожар'
HARPYIA_MODEL = os.getenv('HARPYIA_MODEL') or 'medium'
HARPYIA_LANGUAGE = os.getenv('HARPYIA_LANGUAGE') or 'ru'

# Check if NVIDIA GPU is available
DEVICE = "cuda" if torch.cuda.is_available() else "cpu"

# Load the Whisper model:
model = whisper.load_model(HARPYIA_MODEL, device=DEVICE)

app = Flask(__name__)

@app.route("/")
def hello():
    return "To recognize an audio file, upload it using a POST request with '/recognize' or '/recognize_number' route."

def recognize_files(handler_fn):
    if not request.files:
        abort(400)

    results = []

    for filename, handle in request.files.items():
        # 
        temp = NamedTemporaryFile()
        handle.save(temp)
        result = model.transcribe(temp.name, language=HARPYIA_LANGUAGE, initial_prompt=HARPYIA_PROMPT)
        results.append({
            'filename': filename,
            'transcript': handler_fn(result['text']),
        })

    print(results, file=sys.stderr)
    return {'results': results}

@app.route('/recognize', methods=['POST'])
def recognize():
    return recognize_files(lambda text: text)

@app.route('/recognize_number', methods=['POST'])
def recognize_number():
    return recognize_files(transfer_and_clean)

def transfer_and_clean(input_string):
    number_mapping = {
        "один": "1",
        "два": "2",
        "три": "3"
    }

    for word, number in number_mapping.items():
        input_string = input_string.replace(word, number)
    
    input_string = re.sub(r'[^\d]+', '', input_string)
    
    return input_string

